==> openshift-client-4.13.1-sources.jar: io/fabric8/openshift/client/dsl/internal/CSISnapshotControllerOperationsImpl.java <==

                
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.DoneableCSISnapshotController;
import io.fabric8.openshift.api.model.operator.v1.CSISnapshotController;
import io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList;
import io.fabric8.openshift.api.model.operator.v1.DoneableCSISnapshotController;

import java.util.Map;
import java.util.TreeMap;


public class CSISnapshotControllerOperationsImpl extends OpenShiftOperation<CSISnapshotController, CSISnapshotControllerList, DoneableCSISnapshotController, Resource<CSISnapshotController, DoneableCSISnapshotController>> {

  public CSISnapshotControllerOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public CSISnapshotControllerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("csisnapshotcontrollers"));
    this.type = CSISnapshotController.class;
    this.listType = CSISnapshotControllerList.class;
    this.doneableType = DoneableCSISnapshotController.class;
  }

  public CSISnapshotControllerOperationsImpl newInstance(OperationContext context) {
    return new CSISnapshotControllerOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> openshift-client-5.3.0-sources.jar: io/fabric8/openshift/client/dsl/internal/CSISnapshotControllerOperationsImpl.java <==

                            
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.CSISnapshotController;
import io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerBuilder;
import io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList;

import java.util.Map;
import java.util.TreeMap;


public class CSISnapshotControllerOperationsImpl extends OpenShiftOperation<CSISnapshotController, CSISnapshotControllerList, Resource<CSISnapshotController>> {

  public CSISnapshotControllerOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public CSISnapshotControllerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("csisnapshotcontrollers"));
    this.type = CSISnapshotController.class;
    this.listType = CSISnapshotControllerList.class;
  }

  public CSISnapshotControllerOperationsImpl newInstance(OperationContext context) {
    return new CSISnapshotControllerOperationsImpl(context);
  }

  @Override
  public CSISnapshotController edit(Visitor... visitors) {
    return patch(new CSISnapshotControllerBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
